gleeps_stdlib

Package Version Hex Docs

⚠️ Deprecated

Since publishing this I’ve figured out a better way to achieve what this was meant to.
Honestly don’t use this, if I could remove it i would.

A copy of the gleam_stdlib slightly adjusted for use with gleeps bots.

The primary change is that io.print functions call different @external functions.
This is done to redirect a bot’s print output to the console-out websocket(s) for the user that bot belongs to.


Attribution

The gleam_stdlib is licenced under the Apache-2.0 license.

Everything in ./src/gleeps/stdlib/ except io.gleam and the import statements in each file is the original sourcecode.

io.gleam has the same function definitions as the original module, but calls different @external functions, and the comments differ.

Search Document