gleeps/stdlib/io

Values

pub fn print(string: String) -> Nil

Write something to the console associated with your account.

pub fn print_error(string: String) -> Nil

Write something as an error to the console associated with your account.

pub fn println(string: String) -> Nil

Write something to the console associated with your account. Appends a newline.

pub fn println_error(string: String) -> Nil

Write something as an error to the console associated with your account. Appends a newline.

Search Document