This contains a copy of the gleam_stdlib which is licenced under the Apache-2.0 license.

Everything in ./src/gleeps/stdlib/ except io.gleam and the import statements in each file is the original sourcecode.

io.gleam has the same function defintions as the original module, but calls different @external functions, and the comments differ.

Search Document